Loading the Boundary Polygon Data of Tarim River Basin
Source:R/cn_typical_region.R
load_tarim_basin.RdLoading the Boundary Polygon Data of Tarim River Basin
Examples
load_tarim_basin()
#> Simple feature collection with 1 feature and 0 fields
#> Geometry type: POLYGON
#> Dimension: XY
#> Bounding box: xmin: 73.44696 ymin: 34.50797 xmax: 96.38308 ymax: 43.85645
#> Geodetic CRS: WGS 84
#> # A tibble: 1 × 1
#> geometry
#> <POLYGON [°]>
#> 1 ((91.12191 43.49392, 91.12722 43.49928, 91.12806 43.50373, 91.12857 43.50687,…